-- File................: Top_Level.vhd
-- Function............: RTAX-S EDAC SRAM Test
-- Person Responsible..: Steven Swanstrom (Actel Corporation)
-- Version.............: 1.00
-- Last Updated........: 12-09-2005
-- Component of........: 
-- Components Required.: 
-- Compilation Notes...:
--
-- Revision History:
-- 

-- Functional Description:
--
 
LIBRARY IEEE;
USE IEEE.std_logic_1164.all;
USE IEEE.std_logic_arith.all;
LIBRARY axcelerator;                   --Required for simulation due to instanciated clkints
USE Axcelerator.all;        

entity Top_Level is

  port(
       SRAM_WDATA    : in std_logic_vector(7 downto 0);
       SRAM_WADDR    : in std_logic_vector(7 downto 0);
       SRAM_RDATA    : out std_logic_vector(7 downto 0);
       SRAM_RADDR    : in std_logic_vector(7 downto 0);
       RSTn          : in std_logic;
       CLK           : in std_logic;
       WE            : in std_logic;
       RE            : in std_logic;
       STOP_SCRUB      : in std_logic;
       SLOWDOWN        : out std_logic;
       ERROR           : out std_logic;
       CORRECTABLE     : out std_logic;
       SCRUB_CORRECTED : out std_logic;
       CADDR           : out std_logic_vector(7 downto 0);
       SCRUB_DONE      : out std_logic;
       TMOUTFLG        : out std_logic
       );

end Top_Level;

architecture rtl of Top_Level is

-----------------------------------------------------------
-- SIGNAL DECLARATIONS
-----------------------------------------------------------
    signal Reg_sram_wdata : std_logic_vector(7 downto 0) ;
    signal Reg_sram_waddr : std_logic_vector(7 downto 0) ;
    signal Reg_sram_rdata : std_logic_vector(7 downto 0) ;
    signal Reg_sram_raddr : std_logic_vector(7 downto 0) ;




-----------------------------------------------------------
-- COMPONENT DECLARATIONS
-----------------------------------------------------------

component AX_EDAC_SRAM256X8_EFLAGS is
  port(WDATA           : in std_logic_vector(7 downto 0);
       WADDR           : in std_logic_vector(7 downto 0);
       RADDR           : in std_logic_vector(7 downto 0);
       WE              : in std_logic;
       RE              : in std_logic;
       RSTN            : in std_logic;
       CLK             : in std_logic;
       STOP_SCRUB      : in std_logic;
       RDATA           : out std_logic_vector(7 downto 0);
       SLOWDOWN        : out std_logic;
       ERROR           : out std_logic;
       CORRECTABLE     : out std_logic;
       SCRUB_CORRECTED : out std_logic;
       CADDR           : out std_logic_vector(7 downto 0);
       SCRUB_DONE      : out std_logic;
       TMOUTFLG        : out std_logic);
end component;


begin

--Instantiate the sync'ing registers

sync_in : process (RSTn, CLK, SRAM_WDATA, SRAM_WADDR)
  begin
    if (RSTn = '0') then
        Reg_sram_wdata <= x"00";
        Reg_sram_waddr <= x"00";
    else if (CLK'event and CLK = '1') then
        Reg_sram_wdata <= SRAM_WDATA;
        Reg_sram_waddr <= SRAM_WADDR;
    end if;
	end if;
   end process sync_in;

sync_out : process (RSTn, CLK, SRAM_RADDR)
  begin
    if (RSTn = '0') then
        Reg_sram_raddr <= x"00";
		SRAM_RDATA     <= x"00";
    else if (CLK'event and CLK = '1') then
        SRAM_RDATA <= Reg_sram_rdata;
        Reg_sram_raddr <= SRAM_RADDR;
    end if;
	end if;
   end process sync_out;



--Instantiate the EDAC RAM



TestRAM :  AX_EDAC_SRAM256X8_EFLAGS port map
  (
       WDATA           =>  Reg_sram_wdata,
       WADDR           =>  Reg_sram_waddr,
       RADDR           =>  Reg_sram_raddr,
       WE              =>  WE,
       RE              =>  RE,
       RSTN            =>  RSTn,
       CLK             =>  CLK,
       STOP_SCRUB      =>  STOP_SCRUB,
       RDATA           =>  Reg_sram_rdata,
       SLOWDOWN        =>  SLOWDOWN,
       ERROR           =>  ERROR,
       CORRECTABLE     =>  CORRECTABLE,
       SCRUB_CORRECTED =>  SCRUB_CORRECTED,
       CADDR           =>  CADDR,
       SCRUB_DONE      =>  SCRUB_DONE,
       TMOUTFLG        =>  TMOUTFLG
       );

end rtl;
